aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/rosa/make.go
diff options
context:
space:
mode:
authorOphestra <cat@gensokyo.uk>2026-09-05 05:44:33 +0900
committerOphestra <cat@gensokyo.uk>2026-09-05 06:25:41 +0900
commit5a32f8f9b2f2540495e79cb39ce4a6861553fe79 (patch)
tree47b25144af5edead669b615f3abcc51aedd81096 /internal/rosa/make.go
parent871c701fdbce4a3d43e6e8edc436a2ae93322540 (diff)
internal/rosa: separate native tools from libraries
This removes most redundant runtime arguments and is useful for cross-compilation. Signed-off-by: Ophestra <cat@gensokyo.uk>
Diffstat (limited to 'internal/rosa/make.go')
-rw-r--r--internal/rosa/make.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/internal/rosa/make.go b/internal/rosa/make.go
index 710225a2..1c0e52d6 100644
--- a/internal/rosa/make.go
+++ b/internal/rosa/make.go
@@ -51,8 +51,8 @@ type MakeHelper struct {
var _ Helper = new(MakeHelper)
-// extra returns make and other optional dependencies.
-func (attr *MakeHelper) extra() P {
+// tools returns make and other optional dependencies.
+func (attr *MakeHelper) tools() P {
if attr == nil || !attr.OmitDefaults {
return P{
_make,
@@ -64,6 +64,9 @@ func (attr *MakeHelper) extra() P {
return P{_make}
}
+// inputs is a noop.
+func (*MakeHelper) inputs() P { return nil }
+
// wantsChmod returns whether the build system needs to be generated.
func (attr *MakeHelper) wantsChmod() bool {
return attr != nil && attr.Generate != ""